@@ -618,10 +618,14 @@ extern int  udf_splitup_allocentry_queue(struct udf_alloc_entries *queue, uint32
 extern int  udf_mark_allocentry_queue(struct udf_alloc_entries *queue, uint32_t lb_size, uint64_t data_offset, uint64_t data_length, int mark, struct udf_allocentry **res_firstae, struct udf_allocentry **res_lastae);
 extern int  udf_extent_properties(struct udf_alloc_entries *queue, uint32_t lb_size, uint64_t from, uint64_t to, int *res_all_allocated);
 
-/* statics inside udf */
-SLIST_HEAD(discslist,       udf_discinfo)   udf_discs_list;
-SLIST_HEAD(volumeset_list,  udf_volumeset)  udf_volumeset_list;
-SLIST_HEAD(mountables_list, udf_mountpoint) udf_mountables;
+/* define static list types and structures */
+SLIST_HEAD(discslist,       udf_discinfo);
+SLIST_HEAD(volumeset_list,  udf_volumeset);
+SLIST_HEAD(mountables_list, udf_mountpoint);
+
+extern struct discslist       udf_discs_list;
+extern struct volumeset_list  udf_volumeset_list;
+extern struct mountables_list udf_mountables;
 
 
 #endif	/* _UDF_H_ */
