@@ -2,7 +2,7 @@
 
 /*
  * File "udf_readwrite.c" is part of the UDFclient toolkit.
- * File $Id: udf_readwrite.c,v 1.49 2011/02/01 20:43:41 reinoud Exp $ $Name:  $
+ * File $Id: udf_readwrite.c,v 1.50 2016/04/25 21:01:40 reinoud Exp $ $Name:  $
  *
  * Copyright (c) 2003, 2004, 2005, 2006, 2011
  * 	Reinoud Zandijk <reinoud@netbsd.org>
@@ -229,7 +229,7 @@ int udf_read_session_sector(struct udf_session *udf_session, uint32_t sector, ch
 
 int udf_writeout_session_cache(struct udf_session *udf_session) {
 	struct udf_wrcallback *callback;
-	uint32_t bit, write_bits, error_bits, sector_size;
+	uint32_t bit, error_bits, sector_size;
 	uint32_t num_sectors;
 	int32_t  cache_diff;
 	uint32_t start_sector;
@@ -284,7 +284,6 @@ int udf_writeout_session_cache(struct udf_session *udf_session) {
 	if (udf_session->cache_line_w_present != UDF_READWRITE_ALL_PRESENT) {
 		/* count number of sectors present * (SEQUENTIAL?) */
 		start_sector = 0;
-		write_bits   = 0;
 		cache_diff   = 0;
 
 		DEBUG(printf("Writing out non complete line\n"));
@@ -417,7 +416,7 @@ int udf_read_logvol_sector(struct udf_log_vol *udf_log_vol, uint32_t vpart_num,
 	uint32_t		  length, trans_length, trans_sectors, readahead;
 	uint32_t		  lb_size, sector_size;
 	uint32_t		  ses_sector, ses_offset;
-	int			  error, resolved;
+	int			  error;
 
 	lb_size     = udf_log_vol->lb_size;
 	sector_size = udf_log_vol->sector_size;
@@ -436,7 +435,6 @@ int udf_read_logvol_sector(struct udf_log_vol *udf_log_vol, uint32_t vpart_num,
 	udf_session = udf_partition->udf_session;
 	do {
 		trans_length = length;
-		resolved     = 0;
 		ses_sector   = 0;
 
 		/* TODO optimalisation: could use `trans_valid_len' and `prefetch_sectors' */
@@ -512,7 +510,7 @@ int udf_write_logvol_sector(struct udf_log_vol *udf_log_vol, uint32_t vpart_num,
 	uint32_t lb_size, sector_size;
 	uint32_t ses_sector, ses_offset;
 	uint32_t fid_pos, max_fid_pos;
-	int	 error, resolved, has_fids, recalc_crc, file_type;
+	int	 error, has_fids, recalc_crc, file_type;
 
 	lb_size     = udf_log_vol->lb_size;
 	sector_size = udf_log_vol->sector_size;
@@ -576,7 +574,6 @@ int udf_write_logvol_sector(struct udf_log_vol *udf_log_vol, uint32_t vpart_num,
 	udf_session = udf_partition->udf_session;
 	do {
 		trans_length = length;
-		resolved     = 0;
 		ses_sector   = 0;
 
 		/* determine the translated address and its translation validity length */
@@ -746,7 +743,7 @@ int udf_read_logvol_descriptor(struct udf_log_vol *udf_log_vol, uint32_t vpart_n
 static int udf_write_descriptor(struct udf_log_vol *udf_log_vol, uint32_t vpart_num, struct udf_session *udf_session, uint32_t lb_num, uint32_t dscr_lb_num, char *what, union dscrptr *dscr, struct udf_wrcallback *wrcallback) {
 	uint32_t         dscr_length;
 	uint32_t	 sector_size;
-	uint32_t	 cur_length, sector, num_sectors;
+	uint32_t	 sector, num_sectors;
 	uint8_t		*pos;
 	int		 error, rwflags;
 
@@ -756,7 +753,6 @@ static int udf_write_descriptor(struct udf_log_vol *udf_log_vol, uint32_t vpart_
 	sector_size = udf_log_vol ? udf_log_vol->lb_size : (uint32_t) udf_session->disc->sector_size;
 
 	/* All discriptors have a mimimum size of one sector be it logical or physical */
-	cur_length  = sector_size;
 	num_sectors = 1;
 
 	dscr_length = udf_calc_tag_malloc_size(dscr, sector_size);
