@@ -2,7 +2,7 @@
 
 /*
  * File "udf_verbose.c" is part of the UDFclient toolkit.
- * File $Id: udf_verbose.c,v 1.118 2016/04/25 21:01:40 reinoud Exp $ $Name:  $
+ * File $Id: udf_verbose.c,v 1.120 2018/08/09 20:28:46 reinoud Exp $ $Name:  $
  *
  * Copyright (c) 2003, 2004, 2005, 2006, 2011
  * 	Reinoud Zandijk <reinoud@netbsd.org>
@@ -744,7 +744,7 @@ void udf_dump_extattrseq(uint8_t *start, uint32_t offset, uint32_t impl_offset,
 				if (strncmp((char *) impl_extattr->imp_id.id, "*UDF", 4) == 0)
 					print_attr_space = UDF_REGID_UDF;
 				printf("\t\t\t\tLength of implementation use space     %d\n", iu_l);
-				udf_dump_regid("\t\t\t\tImplemenation use Id", &impl_extattr->imp_id, print_attr_space);
+				udf_dump_regid("\t\t\t\tImplementation use Id", &impl_extattr->imp_id, print_attr_space);
 				is_free_ea_space     = (strcmp((char *) impl_extattr->imp_id.id, "*UDF FreeEASpace")    == 0);
 				is_free_app_ea_space = (strcmp((char *) impl_extattr->imp_id.id, "*UDF FreeAppEASpace") == 0);
 				is_vatlvext_space    = (strcmp((char *) impl_extattr->imp_id.id, "*UDF VAT LVExtension") == 0);
@@ -1130,7 +1130,7 @@ void udf_dump_descriptor(union dscrptr *dscrpt) {
 		case TAGID_ALLOCEXTENT :
 			udf_dump_alloc_extent(&dscrpt->aee, -1);
 			break;
-		case TAGID_INDIRECT_ENTRY :
+		case TAGID_INDIRECTENTRY :
 			udf_dump_indirect_entry(&dscrpt->inde);
 			break;
 		case TAGID_FENTRY :
@@ -1145,7 +1145,7 @@ void udf_dump_descriptor(union dscrptr *dscrpt) {
 		case TAGID_SPACE_BITMAP :
 			udf_dump_space_bitmap(&dscrpt->sbd);
 			break;
-		case TAGID_PART_INTEGRETY :
+		case TAGID_PART_INTEGRITY :
 			udf_dump_unimpl(dscrpt, "partition integrity");
 			break;
 		case TAGID_EXTFENTRY :
