@@ -603,9 +603,7 @@ static const struct {
 size_t
 strlcpy(char *dst, const char *src, size_t size)
 {
-	strncpy(dst, src, size-1);
-	dst[size] = '\0';
-
+	snprintf(dst, size, "%s", src);
 	return strlen(src);
 }
 
